#
# spec file for package FlightGear-data
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define main_version 2020.3
Name:           FlightGear-data
Version:        %{main_version}.18
Release:        bp156.1.1
Summary:        FlightGear base scenery and data files
License:        GPL-2.0-only
Group:          Amusements/Games/3D/Simulation
URL:            https://www.flightgear.org/
Source0:        https://downloads.sourceforge.net/project/flightgear/release-%{main_version}/FlightGear-%{version}-data.txz
# Remove warnings about hidden files to make other rpmlint warnings readable.
Source1:        FlightGear-data-rpmlintrc
NoSource:       0
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  liberation-fonts
BuildRequires:  optipng
BuildRequires:  xz
BuildArch:      noarch
Recommends:     FlightGear-docs-%{version}
Requires:       liberation-fonts

%description
This package contains the base scenery and aircraft for FlightGear.
It must be installed together with the FlightGear flight simulator package.

%package -n FlightGear-docs
Summary:        FlightGear Documentation
Group:          Documentation/Other
Requires:       %{name} = %{version}

%description -n FlightGear-docs
This package contains pdf, text and html documentation for the
FlightGear flight simulator package.

%prep
%setup -q -n fgdata
dos2unix -c ascii Docs/model-combined.eff/README.model-combined.eff
# Remove no longer used textures
rm -Rf ./Textures/Unused
# Remove texture sources in GIMP format
find . -type f \( -name \*\.xcf\.gz -o -name \*\.xcf \) -print -delete
# Delete some build/maintenance scripts
find . -type f -a \( -name \*\.pl -o -name \*\.py -o -name \*\.sh \) -print -delete
# Delete DOS/WINDOWS startup scripts
find . -type f -name \*\.bat -print -delete
# Remove some development files for the Cessna C172p
rm -Rf ./Aircraft/c172p/dev/
# Translation sources (xliff)
find . -type f -name \*FlightGear-*Qt.xlf -print -delete
# More source files
find . -type f -name \*\.zip -print -delete
find . -type f -name \*\.blend -print -delete
# Unbundle fonts
pushd ./Fonts/LiberationFonts/
for font in Liberation*.ttf ; do
  [ -f %{_datadir}/fonts/truetype/$font ] || continue
  rm $font
  ln -s %{_datadir}/fonts/truetype/$font $font
done

%build
# nothing to do

%install
install -d %{buildroot}%{_datadir}/flightgear

for d in `find ./ -mindepth 1 -maxdepth 1  -type d -not -name Docs` ; do
    cp -R $d %{buildroot}%{_datadir}/flightgear/
done
cp version *.xml %{buildroot}%{_datadir}/flightgear/

# Install docs to default docdir
mkdir -p %{buildroot}%{_defaultdocdir}/%{name}
cp -R Docs %{buildroot}%{_defaultdocdir}/%{name}/

# Set permissions for files
find %{buildroot}%{_datadir}/flightgear -type f -exec chmod 0644 "{}" "+"
find %{buildroot}%{_defaultdocdir}/%{name} -type f -exec chmod 0644 "{}" "+"

# Zero length files in docs can be deleted
find %{buildroot}%{_defaultdocdir}/%{name} -type f -empty -print -delete

%fdupes -s %{buildroot}/%{_datadir}/flightgear
%fdupes -s %{buildroot}%{_defaultdocdir}/%{name}

# Recompress png files - do this after deduplication
find %{buildroot} -type f -name '*.png' -print0 | xargs -0 -n 10 -P 0 optipng 2>&1 | grep -E 'Processing:|Output\ file'
# And deduplicate again, repository has some files which only differ in color format
%fdupes -s %{buildroot}/%{_datadir}/flightgear

%files
%license COPYING
%{_datadir}/flightgear/

%files -n FlightGear-docs
%doc AUTHORS NEWS README Thanks
%doc %{_defaultdocdir}/%{name}

%changelog
* Wed Mar 29 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.18
  * https://wiki.flightgear.org/Changelog_2020.3#2020.3.18
* Wed Nov 23 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.17
  * https://wiki.flightgear.org/Changelog_2020.3#2020.3.17
* Tue Apr 12 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.13
  * https://wiki.flightgear.org/Changelog_2020.3#2020.3.13
* Fri Feb  4 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.12
  * https://wiki.flightgear.org/Changelog_2020.3#2020.3.12
* Thu Aug 26 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.11
  * https://wiki.flightgear.org/Changelog_2020.3#2020.3.11
* Thu Jun 10 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.9
  * https://wiki.flightgear.org/Changelog_2020.3#2020.3.9
* Mon Apr  5 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.8
  * http://wiki.flightgear.org/Changelog_2020.3#2020.3.7
* Thu Jan 28 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.6
  * http://wiki.flightgear.org/Changelog_2020.3#2020.3.6
* Mon Jan 11 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.5
  * http://wiki.flightgear.org/Changelog_2020.3#2020.3.5
* Thu Dec 10 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.4
  * No changelog available
* Thu Nov 12 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.2
  * No changelog available
* Wed Oct 28 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.3.1
  * http://wiki.flightgear.org/Changelog_2020.3
* Sat Jun 27 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.1.3
  * http://wiki.flightgear.org/Changelog_2020.1#2020.1.3_point_release
* Thu May 28 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.1.2, for details see
  https://www.flightgear.org/news/flightgear-2020-1-2-released/
- Adjust _constraints to avoid build failures
* Tue May 12 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2020.1.1, for details see
  https://www.flightgear.org/news/flightgear-2020-1-released/
* Sat May  9 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2018.3.5, no changelog provided
- Remove some more sources from data package
- Recompress PNG files with optipng
* Tue Aug 20 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2018.3.4, no changelog provided
* Thu Feb 14 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2018.3.2, no changelog provided
* Tue Jan  8 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Add _constraints file for sufficient disk space
* Tue Dec 18 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 2018.3.1
  * Scenery
    + Improved scenery for Hawaii, the default location for this release.
    + New scenery for Jan Mayen, situated northeast of Iceland.
  * Aircraft Updates
    + "Metadata" has been added to many aircraft, making it easier to find new
    exciting aircraft to fly using the launcher.
    + B-25 : Various bug fixes and minor improvements
    + Cessna 172 : Improved cockpit, interior lighting.
    + Citation II : New panels, radio instruments. Complete remodeling of the
    electric system. System test knob implemented.
    + F4U : new FDM
    + F-14 : V1.8. Improved flight model, particularly at low-speed. Improved cockpit.
    + F-15 : V1.8. Updated flight model, particularly armament mass location.
    Performance optimizations. Autopilot improvements.
    + F-16 : v3.0. Store options. New liveries. Radar performance optimizations.
    Autopilot and system improvements. FDM fixes.
    + Saab 37 Viggen : Version 4.313. Various updates, particularly to radar and armament models.
    + Seneca II: Long range tanks, interior lighting,
    + SpaceShuttle : Milestone-10. Improved interior (including furry velcro),
    launch guidance and orbital plane targeting, more realistic OMS burn procedures, expanded
    systems including circuit breaker simulation and failure modeling.
    + 777: Our flagship airliner now fully supports checklists, allowing you to learn everything
    about the aircraft from within the simulator. Full support to auto-push was also
    implemented. Bug fixes and minor improvements.
* Thu Aug  9 2018 rpm@fthiessen.de
- Minor spec file cleanup.
* Thu Aug  9 2018 stefan.bruens@rwth-aachen.de
- Update to 2018.2.2
  * Cessna 550 Citation II - detailed modelling of avionics,
    improved MP model display, improved flaps modeling
  * Cessna Citation X - avionics improvements,
    improved MP model display
  * North American P-51 Mustang
  * Piper J3 Cub - improvements to water behaviour
  * Saab 37 Viggen - Autopilot, HUD and TI improvements
  * Cessna 172P - FDM, 3D Model, Sound improvements
  * FG1000 glass panel display, based on the Garmin G1000
- Update to 2018.2.1
  * Active Volcanos, including Kilauea, Stromboli, Etna,
  * New Hawaii regional texture definitions
  * Several scenic waterfalls in the Hawaii area
  * New and unique vegetation textures for several
    parts of the world
  * New 3D Objects: Buildings and structures in France,
    Portugal, Spain, UK, USA, Australia and Ukraine
  * Improved airports: Valle del Conlara Airport (SAOS) in
    Argentina, RAF Mount Pleasant (EGYP) in Falkland Islands UK,
    Bordeaux–Mérignac Airport (LFBD) in France and
    King Abdulaziz International Airport (OEJN) in Saudi Arabia.
  * A new glider: Rolladen-Schneider LS4
  * Space Shuttle improvements
  * Cessna 182S
  * Amelia - an animated and hard-working co-pilot for the
    Alouette III capable of taking off and landing
  * Citation II
  * F-14 - various changes including improved carrier operations
  * Robinson R44 helicopter
  * Major DHC-6 Twin Otter update: JSBSim variant added
    (status: experimental), more realistic fuel system in JSBSim,
    significantly more detailed simulation of the electrical
    system including various DC and AC buses, circuit breakers
    and bus tie relay.
- Spec file cleanup/fixes:
  * Skip generation of documentation, everything is pregenerated
  * Drop no longer required tex dependencies
- Remove unnecessary files:
  * Unbundle fonts (liberation-fonts)
  * Obsoletes textures (Textures/Unused/)
  * Texture sources in GIMP format (*.xcf.gz)
* Tue Sep 26 2017 Mathias.Homann@opensuse.org
- Update to 2017.3.1
  * New AI Model Embraer ERJ 190 with Paintkit and
    liveries Default, Helvetic Airways and Finnair.
  * Add tips provided by forum members.
  * Updated Ukraine Intl Liveries 737-300, 737-800, 767-300
  * ERJ90 AI model update, new Tail and Nacelles +
    Adjusted Paintkit
  * New Liveries for ERJ90 AI model
  * Updated Liveries AI ERJ90 with Nacelles Texture
  * Added ERJ90 model to existing Traffic File
  * Remapped 747-400 AI Model (Top of fuselage)
  * 747-400 Liveries for new model mapping
  * Remapped 747-400 Freighter (Top Fuselage)
    and updated Liveries
  * Switch to the latest DESG fonts
    and add the new Weather symbols MP2017 protocol support.
  * Remapped 767-300 (Top of Fuselage). Ajusted Liveries.
    Added pitch
  * Earthview 2.1 - parallax mapping for cloud layer,
    lightning at night, Rayleigh scattering in atmosphere.
  * Bugfix and noise seed option for ALS thrust flame shader
  * Bugfix for ALS HUD effect/filtering interaction
  * AirBaltic Dash8 Texture
  * Update the Italian translation
  * Update the French translation
  * Added Spanish translation for startup tips.
  * LOT, Vueling TAP and Wideroe Liveries for
    733 738 319 321 AT7 and Dash 8
  * Austrian Airlines Liveries for AI models Fokker 70 &
    Embraer ERJ195
  * Air Mauritius Liveries for ATR 72 & A319
  * Austrian Airlines Livery for new 777-200
  * TAM Brazil AI 777-300 Livery
  * Updated 733 AI. Fixed AC model(s) & Winglets Mapping.
    New Windhshield Texture.
  * New 777-300 Livery for Swiss Airlines
  * A350-900 Model addd to Qatar Airways traffic file
  * Fix particle wake for USS Truman
  * Bug Fix to missing performance data error for
    CRJ 1000 AI model.
  * New AI Model B737-900ER incl Paintkit and 5 liveries
* Wed Jun 21 2017 bwiedemann@suse.com
- drop unneccesary TeX logs to fix build-compare
* Thu Mar  9 2017 wk@ire.pw.edu.pl
- Update to 2017.1.2
* Mon Jan 23 2017 opensuse@dstoecker.de
- update to version 2016.4.4
* Sat Jan  7 2017 davejplater@gmail.com
- Fixed boo#987206 by moving license files for third parties to
  the default doc dir and fdupe the flightgear data dir and doc dir
  seperately.
- Split off documentation into a sub package
- Added FlightGear-data-rpmlintrc to suppress many warnigs about
  needed hidden files and make rpmlint output more readable.
* Sun Aug 21 2016 mailaender@opensuse.org
- Update to 2016.2.1
* Sun Mar 20 2016 bosim@opensuse.org
- Added SourceURL
* Mon Mar 14 2016 bosim@opensuse.org
- Update to 2016.1.1
* Wed Nov 25 2015 rpm@fthiessen.de
- Update to 3.7.0
* Mon Sep 23 2013 Mathias.Homann@opensuse.org
- update to 2.12.0
* Tue Mar 19 2013 joop.boonen@opensuse.org
- update to 2.10.0
* Thu Aug 23 2012 thorstenb@flightgear.org
- Fix "OpenGL error 'invalid operation'" error and crash with some
  graphics cards (FlightGear fgdata commit #6b76ef1a)
* Fri Aug 17 2012 thorstenb@flightgear.org
- update to 2.8.0
* Fri Feb 17 2012 thorstenb@flightgear.org
- update to 2.6.0
- fixed FlightGear help system
* Tue Sep  6 2011 highwaystar.ru@gmail.com
- data moved /usr/share/FlightGear -> /usr/share/flightgear
* Tue Sep  6 2011 highwaystar.ru@gmail.com
- update to 2.4.0
- added fdupes macro
* Mon Mar  1 2010 prusnak@suse.cz
- updated to 2.0.0
- apply fixes from Fedora package by Fabrice Bellet <fabrice@bellet.info>
* Fri Jan  4 2008 lmichnovic@suse.cz
- patched tarball with upstream patch fixing mp chat
* Thu Jan  3 2008 lmichnovic@suse.cz
- update to version 1.0.0
* Wed Nov 28 2007 lmichnovic@suse.cz
- update to 0.9.11-pre2 version
* Thu Nov 22 2007 lmichnovic@suse.cz
- updated data from CVS
